@@ -1,9 +1,10 @@
 #!/usr/bin/env python
 # -*- coding: utf-8 -*-
 
+
 def main():
-    print('test')
+    print("test")
 
-if __name__=='__main__':
-   main()
 
+if __name__ == "__main__":
+    main()
