@@ -1,11 +1,16 @@
-import os,sys,json,glob,shutil,uuid,time
+import glob
+import json
+import os
+import shutil
+import sys
+import time
 import unittest
+import uuid
 
-sys.path.insert(0, os.path.abspath(os.path.join(os.path.dirname(__file__), '..')))
-__package__ = 'tests'
+sys.path.insert(0, os.path.abspath(os.path.join(os.path.dirname(__file__), "..")))
+__package__ = "tests"
 # from .context import FinRecord
-from .context import _split_tasks
-from .context import setUpModule
+from .context import _split_tasks, setUpModule
 
 # class TestFinRecord(unittest.TestCase):
 #     def setUp(self):
@@ -27,16 +32,15 @@ from .context import setUpModule
 #         recd1 = self.fr.get_record()
 #         self.assertEqual(recd, recd1)
 
+
 class TestDispatchSplit(unittest.TestCase):
     def test_split(self):
         tasks = [ii for ii in range(10)]
         chunks = _split_tasks(tasks, 5)
-        self.assertEqual(chunks, [[0,2,4,6,8],[1,3,5,7,9]])
+        self.assertEqual(chunks, [[0, 2, 4, 6, 8], [1, 3, 5, 7, 9]])
         # self.assertEqual(chunks, [[0,2,4,6,10],[1,3,5,7,9]])
 
     def test_split_1(self):
         tasks = [ii for ii in range(13)]
         chunks = _split_tasks(tasks, 5)
-        self.assertEqual(chunks, [[0,3,6,9,12],[1,4,7,10],[2,5,8,11]])
-
-        
+        self.assertEqual(chunks, [[0, 3, 6, 9, 12], [1, 4, 7, 10], [2, 5, 8, 11]])
