@@ -1,14 +1,14 @@
 """Test `Submission.generate_jobs` with different group size."""
 
+import json
 import os
 import sys
-import json
-from unittest import TestCase
 from pathlib import Path
+from unittest import TestCase
 
-sys.path.insert(0, os.path.abspath(os.path.join(os.path.dirname(__file__), '..')))
-__package__ = 'tests'
-from .context import Machine, Resources, Task, Submission
+sys.path.insert(0, os.path.abspath(os.path.join(os.path.dirname(__file__), "..")))
+__package__ = "tests"
+from .context import Machine, Resources, Submission, Task
 
 # 99 tasks in total
 # group_size - expected_ntasks
@@ -22,7 +22,7 @@ group_ntasks_pairs = [
 
 cwd = Path(__file__).parent
 with open(cwd / "jsons" / "machine.json") as f:
-    j_machine = json.load(f)['machine']
+    j_machine = json.load(f)["machine"]
 with open(cwd / "jsons" / "resources.json") as f:
     j_resources = json.load(f)
 with open(cwd / "jsons" / "task.json") as f:
@@ -34,7 +34,7 @@ class TestGroupSize(TestCase):
         for group_size, ntasks in group_ntasks_pairs:
             with self.subTest(group_size):
                 machine = Machine.load_from_dict(j_machine)
-                j_resources['group_size'] = group_size
+                j_resources["group_size"] = group_size
                 resources = Resources.load_from_dict(j_resources)
                 tasks = [Task.load_from_dict(j_task) for _ in range(99)]
                 submission = Submission(".", machine, resources, task_list=tasks)
