@@ -1,50 +1,65 @@
-import os,sys,json,glob,shutil,uuid,time
+import glob
+import json
+import os
+import shutil
+import sys
+import time
 import unittest
+import uuid
 from pathlib import Path
-from unittest.mock import MagicMock, patch, PropertyMock
+from unittest.mock import MagicMock, PropertyMock, patch
+
+sys.path.insert(0, os.path.abspath(os.path.join(os.path.dirname(__file__), "..")))
+__package__ = "tests"
+from .context import LazyLocalContext, setUpModule
+
 
-sys.path.insert(0, os.path.abspath(os.path.join(os.path.dirname(__file__), '..')))
-__package__ = 'tests'
-from .context import LazyLocalContext
-from .context import setUpModule
 class TestLazyLocalContext(unittest.TestCase):
-    def setUp(self) :
+    def setUp(self):
         # os.makedirs('loc', exist_ok = True)
         # os.makedirs('loc/task0', exist_ok = True)
         # os.makedirs('loc/task1', exist_ok = True)
-        shutil.copytree(
-            src='test_context_dir/',
-            dst='tmp_lazy_local_context_dir/')
+        shutil.copytree(src="test_context_dir/", dst="tmp_lazy_local_context_dir/")
 
         self.lazy_local_context = LazyLocalContext(
-            local_root='tmp_lazy_local_context_dir/'
+            local_root="tmp_lazy_local_context_dir/"
         )
-        submission = MagicMock(work_base='0_md/')
+        submission = MagicMock(work_base="0_md/")
         self.lazy_local_context.bind_submission(submission)
 
     def tearDown(self):
-        shutil.rmtree('tmp_lazy_local_context_dir/')
+        shutil.rmtree("tmp_lazy_local_context_dir/")
 
     def test_upload(self):
         pass
 
-    def test_download(self):        
+    def test_download(self):
         pass
 
     # TODO: support other platforms
-    @unittest.skipIf(sys.platform != 'linux', "not linux")
+    @unittest.skipIf(sys.platform != "linux", "not linux")
     def test_block_call(self):
-        code, stdin, stdout, stderr = self.lazy_local_context.block_call('ls')
-        self.assertEqual(stdout.readlines(), ['bct-1\n',
-            'bct-2\n', 'bct-3\n', 'bct-4\n', 'dir with space\n', 'graph.pb\n'])
+        code, stdin, stdout, stderr = self.lazy_local_context.block_call("ls")
+        self.assertEqual(
+            stdout.readlines(),
+            [
+                "bct-1\n",
+                "bct-2\n",
+                "bct-3\n",
+                "bct-4\n",
+                "dir with space\n",
+                "graph.pb\n",
+                "some_dir\n",
+            ],
+        )
         self.assertEqual(code, 0)
 
-        code, stdin, stdout, stderr = self.lazy_local_context.block_call('ls a')
+        code, stdin, stdout, stderr = self.lazy_local_context.block_call("ls a")
         self.assertEqual(code, 2)
         # self.assertEqual(stderr.read().decode('utf-8'), "ls: cannot access 'a': No such file or directory\n")
-        err_msg = stderr.read().decode('utf-8')
-        self.assertTrue('ls: cannot access' in err_msg)
-        self.assertTrue('No such file or directory\n' in err_msg)
+        err_msg = stderr.read().decode("utf-8")
+        self.assertTrue("ls: cannot access" in err_msg)
+        self.assertTrue("No such file or directory\n" in err_msg)
 
     # def test_block_checkcall(self) :
     #     self.job  = LazyLocalContext('loc', None)
@@ -57,7 +72,7 @@ class TestLazyLocalContext(unittest.TestCase):
     #     self.assertEqual(stdout.readlines(), ['task0\n','task1\n'])
     #     with self.assertRaises(RuntimeError):
     #         stdin, stdout, stderr = self.job.block_checkcall('ls a')
-            
+
     # def test_file(self) :
     #     self.job = LazyLocalContext('loc', None)
     #     self.assertFalse(self.job.check_file_exists('aaa'))
@@ -66,7 +81,6 @@ class TestLazyLocalContext(unittest.TestCase):
     #     self.assertTrue(self.job.check_file_exists('aaa'))
     #     tmp1 = self.job.read_file('aaa')
     #     self.assertEqual(tmp, tmp1)
-        
 
     # def test_call(self) :
     #     self.job = LazyLocalContext('loc', None)
@@ -84,4 +98,3 @@ class TestLazyLocalContext(unittest.TestCase):
     #     self.assertEqual(r, 0)
     #     self.assertEqual(o, None)
     #     self.assertEqual(e, None)
-
